#[repr(u32)]pub enum SlotStatus {
Processed,
Rooted,
Confirmed,
FirstShredReceived,
Completed,
CreatedBank,
Dead(String),
}Expand description
The current status of a slot
Variants
Processed
The highest slot of the heaviest fork processed by the node. Ledger state at this slot is not derived from a confirmed or finalized block, but if multiple forks are present, is from the fork the validator believes is most likely to finalize.
Rooted
The highest slot having reached max vote lockout.
Confirmed
The highest slot that has been voted on by supermajority of the cluster, ie. is confirmed.
FirstShredReceived
First Shred Received
Completed
All shreds for the slot have been received.
CreatedBank
A new bank fork is created with the slot
Dead(String)
A slot is marked dead
Implementations