ReplicaDeshredTransactionInfo

Struct ReplicaDeshredTransactionInfo 

#[repr(C)]
pub struct ReplicaDeshredTransactionInfo<'a> { pub signature: &'a Signature, pub is_vote: bool, pub transaction: &'a VersionedTransaction, pub loaded_addresses: Option<&'a LoadedAddresses>, }
Information about a transaction after deshredding (when entries are formed from shreds). This is sent before any execution occurs. Unlike ReplicaTransactionInfo, this does not include TransactionStatusMeta since execution has not happened yet.

Fields

signature: &'a Signature

The transaction signature, used for identifying the transaction.

is_vote: bool

Indicates if the transaction is a simple vote transaction.

transaction: &'a VersionedTransaction

The versioned transaction.

loaded_addresses: Option<&'a LoadedAddresses>

Addresses loaded from address lookup tables for V0 transactions. Resolution uses the rooted bank, so address lookup tables created between the root slot and the current slot will not resolve. This field is None for legacy transactions, when the transaction has no address table lookups, when ALT resolution is not enabled by the plugin, or when resolution fails (e.g. the lookup table account does not exist at the root slot).